---
title: "Stefan Molyneux and the Definition of Love"
date: 2020-12-27T17:19:17Z
tags: ["love","aquinas","hedonism","materialism"]
topics: ["philosophy","theology"]
image: /img/what-is-love1.jpg
draft: false
---

I am hesitant to do back-to-back critiques of Stefan Molyneux, because I don’t want the blog to become the “Contra Molyneux” journal. However, in his [**Christmas podcast**](https://podcasts.apple.com/us/podcast/4748-jesus-socrates-christmas-and-morality/id552010683?i=1000503447352), Stefan made a number of titillating and curious assertions, that I just couldn’t resist. He did not offer a thorough defense of any of them in the podcast, but we can excuse this on the ground that at least some of these are defended elsewhere, and were only presuppositions necessary for the present discussion.

However, there are three specific assertions that I have heard him make many times over the last 10 years without a proper defense, and I want to explore and critique them, here. He asserts:

- Love is the involuntary response to virtue, for the virtuous (just as healthy weight is the involuntary response to good diet)
- These logical corollaries follow necessarily: hatred is the involuntary response to vice, for the virtuous. Hatred is the involuntary response to virtue, for the vicious; love is the involuntary response to vice, for the vicious.
- Love is not subject to your will. You can will virtue. You can will moral discernment. You can will judgment. You cannot will love.

Thinking about these assertions (and much of the context around them, when they are asserted), there are a few implications that stand out immediately.

- First, though the implication is extremely vague, it seems that Stefan thinks of love as some sort of psychologically determined state. Love is, perhaps, something like an emotion or an impulse — like anger, or flinching from pain, or sexual arousal, yet not identical to these things.
- Second, not being a product of the will, and yet being committed to free will as necessary for morality, Stefan strongly suggests here that the psychological state of love and hate are beyond the reach of moral judgment. I cannot reasonably praise or blame you for your love or your hatred, any more than I can reasonably praise or blame you for your anger, your fear, or your whincing when I poke you with a needle.
- And yet, thirdly, love is entirely dependent upon virtue, which by vague implication here, seems to be some sort of inherent property or state of being, roughly understood as “lovable”. To put it in simpler (tautological) terms, one must be lovable to the lovable, in order to be loved by the lovable.

### Apetizer: Virtue and The Good

Before we get into the definition itself, I want to raise a preface concern. Stefan seems to muddle the distinction between between virtue and *the good*. He keeps talking about the pursuit of *virtue*, when he really seems to mean the pursuit of *the good*. But it’s not entirely clear, because he uses the term “virtue” in a number of different senses.

Stefan argues that people want to see themselves as virtuous and they do this by either pursuing the good opinion of “the mob”, or by pursuing self-love. Those who pursue the opinion of “the mob”, according to Stefan, are pursuing self-hatred, since they surrender their moral autonomy to others. For those who pursue self-love, however (and since love is an involuntary response to virtue) it is really virtue they pursue.

But according to Aristotle, virtue is merely the means by which we achieve the good. Virtue is not entirely end itself. Despite the fact that some virtues can be ends, they are *all means* to *the good*. But Stefan seems to have either abandoned the idea of the good altogether, or merged it with virtue itself.

Without a clear understanding of what the ultimate end is — i.e., *the good* — we have no standard by which to judge what behavior constitutes a virtue, and what behavior constitutes a vice. It is *the good* that is the bullseye of the target, toward which the arrows of virtue aim.

Stefan, of course, offers a negative conception of the good: self-ownership and the non-aggression principle grounded in his “UPB” (something I will have to cover in a different critique, because it’s too big to go into here). But Aristotle would have been entirely dissatisfied with this. It is not enough to tell people what they *must not* do, in order to avoid being vicious. The avoidance of vice, in the narrow sense that Stefan defines it in UPB, is not the same thing as the cultivation of virtue. The duty of the philosopher is to explain what the life of man is, and *what it is for*. So far, all Stefan has offered is an explanation of the various things that are *not* the purpose.

To put this in more concrete terms, I have no reasonable ground on which to praise or blame a man for the way he uses his intellect, or his strength, or even what moral virtues he has cultivated, if the only moral measure I have, is that he has not violated UPB.

### The Definition and Its Problems

Stefan’s definition of love is almost as old as his podcast. I remember him discussing this in some of his very early commuter monologues, and it surprises me that no one has bothered to question it, in light of the fact that there are so many obvious issues with it, and the fact that there are alternatives that are much more rigorous. Let’s discuss some of those problems here.

First, it is not at all clear what this “involuntary response” is. He rejects direct identifications with affection, desire, or concern, but is handy with metaphors like the one above (likening it to weight). I have heard him suggest in the past that love is only similar to emotion, but something “deeper”. Presumably, this goes for hate, as well (since he now asserts the logical corollaries). This would also be something like rage, or suspicion, or disgust, but not identical to it; “deeper” and yet, equally unwilled. Modern psychology would characterize it vaguely as some sort of “attachment” or “bond” or emotional interrelatedness. Something that is not as transient as sexual arousal or hunger, but not permanent either (like the difference between weather and climate). However, modern psychology would not characterize love as a moral phenomenon at all. So, if Stefan is defending a psychological explanation of love with a moral component, he needs to explain how that works.

Second, while this definition does not necessarily contradict his free will position, it does deny that love and hate are free choices — and in particular, *deliberate* choices. Stefan needs to explain how he reconciles the two positions. What’s more, lacking any deliberate or voluntary nature, love and hate cannot be rational states of mind; at best, non-rational or pre-rational. On an Aristotelian understanding, this would mean love and hate are phenomena we should expect to see in lower animals like dogs or horses. But we do not. Virtue requires practical reason minimally, and pure reason in some cases, in order to be achieved, because they are required for deliberate desire, and choice. Animals lack this. But if deliberate desire is something rational, then we’d need an explanation as to why love could not be either. Stefan has none on offer.

Third, Aristotle argues that virtue is to be found *in the doing*, not *in the having*. What he means by this, is that virtue would become an incoherently diluted term, if it could be applied to, say, someone in a coma. This goes also to my above complaint about the muddling of *the good* with virtue. Stefan seems to be arguing from a view that men *have* (or have not) virtue. Not that they have cultivated dispositions *to act* (or act not) in virtuous ways. But Stefan also accepts that it is *actions* that we judge to be good or evil. So, it’s not at all clear how the object of love would *not* be the actions, rather than the actor. For example, why would I not have this involuntary reaction at *the action* of puppies being petted, rather than at the person doing the petting (pardon the silly example)?

Fourth, Aristotle clarifies that accumulated repetitions of virtuous behavior will *dispose a man toward* acting virtuously (similar to the way practice can make an average sportsman into a superstar). But this man “possesses” virtue only insofar as he acts it out. “Being virtuous”, therefore, is not “being virtue” itself. Which is to say, character is judged with reference to an external standard; the character is not the standard itself. This is important, because it is not clear how the perfection of character is to be recognized, let alone possible. To put it more plainly, let’s say I am an unformed youngster who’s “involuntary responses” have been largely indefinite and arbitrary up to now. What would be necessary to get to the correct “involuntary responses”? If this is something that is as determinate as the way my body responds to nutrition, or respiration, why would such a thing as “character building” even be necessary? Why wouldn’t the correct “involuntary responses” just be there, once I reached the right age (like a beard on post-pubescent boys). This objection may seem churlish at first. But it’s essential. Aristotle argued that virtue was impossible in rocks and oak trees, because they lacked the rational part of the soul. The part that needed to be oriented toward *the good*. The part that *didn’t* come naturally to us. We have the potential to act in virtuous ways, by nature, but not the *actuality* of virtue, by nature. Thus, we must make a deliberate choice ourselves to actualize that potential. It is not clear to me why this would not extend to love, as well. Particularly, self-love. Proper diet, proper exercise, prudence in relationships, courage in the face of danger; these are very difficult things to get right, and practicing them is unpleasant and often fraught with danger itself. If we were to follow our determined impulses, we would avoid that work. Even Aristotle recognized this. So, at least self-love is in fact, it seems to me, a deliberate choice. Why is that not also the case with others?

Fifth, the ancient Greeks had a very sophisticated psychological understanding of love. There is brotherly affection, filial affection (parent-to-child), romantic attraction, erotic attraction (yes, they distinguished between the two), loyalty to ones’ countrymen, and piety toward the gods. Each of these forms of love is different not just in degree, but in quality, and come complete with their own sets of expectations, duties, pleasures, pains, and moral requirements. Stefan’s definition, however, is a binary with indiscriminate boundaries. You are either virtuous or you are not, and I know because I can “feel” the involuntary response (which isn’t quite affection or desire, but something like it). If this feeling fades, then I know you are no longer virtuous enough to evoke it. There is no guidance as to the quality of the feeling (e.g., how to identify the difference between filios and eros), as to the intensity of the feeling (except that it is either there, or it is not), or as to the standard by which we might judge the appropriateness of various behaviours arising from the involuntary response. This understanding of love is uniform and indiscriminate. Presumably, all virtue gets exactly the same response, and the behavior arising from that response is equally as uniform. But what is it?

Sixth, the linkage between the rational evaluation of action, and the involuntary response, is missing. For Aristotle, an act is judged virtuous if it contributes in some way to the actualization of some potential contained within a rational being. So, regulation of diet, such that it results in good health, is virtuous behavior, and given the name “temperance” (or “abstinence” in extrema). Aristotle did not hold that temperance would result in love for the man who diets. He would have said that temperance warranted praise or admiration for doing what is good for man, but that is not the same as, say, filial affection or comradeship. What’s more, you could have filial affection for a man, while still condemning some particular vice he exhibited (say, smoking, for example). So, the question is, how do we get from a rational judgment, to an involuntary response to that judgment? And why would that involuntary response necessarily be *love*? If Stefan wants to say that the rational assent just is the involuntary response (just as in, say, mathematics or logic, where we cannot help but assent to the conclusions, if true), then either he’s distancing his definition from the emotional model he began with, or he’s suggesting that rational assent is itself some sort of psychologically determined state (perhaps not love, but something else)? This cannot be correct. So, further explanation is needed.

### An Alternative Hypothesis

Aristotle does not seem to offer a comprehensive theory of love in any of his writings. However, there are tantalizing hints and asides throughout that are extremely evocative, and explain where Thomas Aquinas gets some of his own ideas. In the Rhetoric, for example, Aristotle flatly asserts in one aside, that love is “wishing good for another man”. This is very close to, but not quite, what Aquinas ultimately settled upon.

Aquinas’ definition combines his understanding of Aristotle with his neo-Platonic background, and it stands in direct contradiction to Stefan’s definition. Put plainly, Aquinas argued that love is “to *will* the good of the other, for the sake of the other”, or “to *will* the good of the other, for the sake of the good”. There is some dispute over the precise wording, but the succinctness of the definition makes it fairly clear, even to modern eyes. Let me try to break down the language and expand on what he had in mind.

Note that I emphasized “will”. This was Aquinas’ doing. Aristotle was not so clear (which is why the usual translation is “wish”). For Aqinas, these were definitely not the same things. For Aquinas, willing and acting are not synonymous but they are fixed together in a determinate relationship. If you fail to act, you lack the will. If you possess the will, you act. The will is that faculty of mind that actualizes the potential for action. Thus, wishing, desiring, hoping, and yearning are all different things, because they don’t *necessarily* bring about action.

Aquinas had a hierarchical understanding of the good that combined his neo-Platonism and his study of Aristotle. Like Aristotle, he accepted a conception of the good that involved natural excellence (arete), which is attained by cultivating the philosophical virtues (courage, prudence, justice, and temperance). But unlike Aristotle, he argued for the transcendent good in the beatific vision of God, which on neo-Platonic ground, is synonymous with the absolute good. The theological virtues of faith, hope, and charity, granted to us by God through grace, are necessary for reaching beyond the natural, and achieving this good. We can of course, debate the reality of neo-Platonic transcendence. But the point here, is that love (like faith and hope) is a special variety of virtue, but it is still a *habit of the soul*, on Aristotle’s model. When acted out correctly, it helps us attain the good. To love another, is to act in such a way as to help them attain the good as well. The extent to which the natural philosophical virtues aid in the aquisition of the theological virtues, and achieve the transcendent good, is the extent to which they deserve praise. This is why overtly Christian athletes and soldiers often thank God for their successes.

Thus, through Aquinas, we have a definition of love that succinctly unifies Aristotelian natural virtue with the neo-Platonic transcendent good, characterizes that definition in a way that renders it independent of (but not totally irrelevant to) man’s psychology, and affords us a definite standard by which we can govern our own behavior, and judge it as loving or not, independently of our own subjective experience. Am I willing the good for this person?

### Love and Sacrifice

Affections and desires may draw us together to begin with, but to maintain a family or a community requires love, on the definition of Aquinas: a willingness to do good for one another, indepdendently of our affections or desires. The latter can change with the hours of the day. The former, however, is a *virtue*. Thus, once it is habituated, it will be constant in spite of changing moods.

We can all recall moments when doing good was accompanied by undesirable feelings. For example, the day you had to teach your child to accept separation, or the day you had to correct a colleague’s mistake. On Aquinas’ view these are both *acts of love*, because they are attempts to will the good of another. But isn’t this the same sort of indiscriminate character found in Stefan’s definition? If making love to my wife, and correcting a colleague’s mistake are both equally acts of love, then what exactly are we talking about here?

Well, Aquinas did not think that all acts of love were of *equal value*. There are different categories of love, and each one up the hierarchy entails a more significant giving of the self, than the previous. Suppressing my yearning to comfort my child when I am trying to teach him the necessity of separation is, in some small sense, a sacrificial act. Albeit, a small one. One piece of my relationship with my child is sacrificed, in order to graduate to something better. Willing his good — loving him — means giving something up. Likewise all the way up the ladder. The love that Christ exhibited by sacrificing his human nature on the cross, is (at least, according to Aquinas) infinitely more valuable than any love mankind is capable of, even collectively, because it restored man’s relationship to God. But it is the *same love in principle*, because it is the willing of the good of the other.

At this point, Stefan and other neo-Randians will strenuously object. A doctrine of self-sacrifice is a doctrine of self-hatred, they will say. To call what was done to Christ on the cross “love” is perverse and macabre, because it is the same as loving death itself. It is the same as saying the only path to the good, and the only way to love, is to embrace death.

This is a caricature and a false dichotomy. It recasts willing the good of the other, for the sake of the other, as a kind of zero-sum competition of self-worths pitted against each other, until one succumbs. It suggests that all sacrifice in the pursuit of the good of another, is necessarily willing an evil for oneself. But the latter does not logically follow from the former, even if we set aside the potential transcendence of the soul. As noted above, when I sacrifice the part of the relationship I have with my child in this moment, in order to teach him the utility of separation, what comes of it is increased good *for both of us*. Likewise, with Christ’s ultimate sacrifice on the cross.

Rand’s mistake, then, was twofold. First, she elevates man’s life itself, to the state of an end-in-itself. Living, and in particular living the unfettered freedom of the rational will, is the highest value, and anything else is a distraction at best. Second, she treats every particular interaction in isolation as a transaction. So, there is no possibility of a transition from one set of goods, to another. The sacrifice of that piece of a relationship with my child is a net loss, when looked at in that moment. Anything that follows, good or not, is irrelevant. This is to mistake growth in the pursuit of the good, for consequentialism.

Aristotle would say concepts like “sacrifice” don’t even enter into the analysis. Such a father was simply exhibiting the natural virtues of temperance and prudence, by foregoing a pleasurable indulgence of his child, in order to maximize the good of his family. But the point is that if we look at these instances in a broader context, it is clear that willing the good of the other — even where self-sacrifice is present in the moment — is not at zero-sum proposition. If the most extreme limiting case we can conjure, in the example of Christ on the cross, is open to this interpretation (and, as we’ve seen, it is), then there is no reason to see anything of lesser value in a different way. All it suggests is that willing the good of the other will make demands upon us that are sometimes beyond the burdens we are used to bearing.

### The Example of Christ

Some of you will be wondering why I keep pulling Christ into this analysis. Why does a definition of love require a bunch of Christian dogma? Well, setting asid the fact that Aquinas’ definition doesn’t actually require adherence to the religion’s dogmas, and the fact that I think Aquinas’ definition is the only one that makes any sense, it’s because Stefan made a point of praising Jesus as one of the greatest “moral innovators” of history. He thinks Christ is praiseworthy on moral grounds, even as he gives us a definition of love that is utterly opposed to Christ’s own preachings.

If you think love is an involuntary response to natural virtue, and hate an involuntary response to natural vice, then you should condemn Jesus as both incoherent and a moral reprobate. Two obvious examples spring immediately to mind. First, Matthew 22:36, in which Jesus commands us to love our neighbors as ourselves. What sense does that make, if love is an *involuntary response*? I can no more love my neighbor, than I can admire his lime-green sofa. Even worse, what perversity would it be to command someone to love his enemies (Matthew 5:44), when *hate* is the natural involuntary response to vice (assuming our enemies are vicious, of course)? At best, Christ would be a wicked troll, for burdening us with such confounding advice. At worst, a sadistic monster.

However, if we take Aquinas’ definition, things suddenly make a lot more sense. To love your neighbor as yourself is simply to act in ways that *do good* to your neighbor, as you would *do good* for yourself, and that encourage his own pursuit of the good. Likewise, with loving your enemies. What’s more, since love is a virtue (albeit a theological virtue), it is a *choice*, and as such is subject to judgements of praise or blame. Love is no longer an amoral phenomenon, but a deeply moral feature of human life.

### Conclusion

In the end, then, all we need to complete the Thomistic picture, is an effective method for converting the principle into practice. What is the good in each situation, and what would it look like to will it for another? The Thomists, of course, would commend the scriptures to you, and the help of a learned priest. But for those who are irreligious, there are many modern virtue ethicists working in the area of applied ethics, that can help. Martha Nussbaum and Rosalind Hursthouse come to mind, but there are others. In any case, application is beyond the scope of this critique.

```[Imported from exitingthecave.com on 28 November 2021]```

