---
title: "Free Speech From Property Rights"
author: "Murray Rothbard"
image: /img/rothbard.jpg
era: "Twentieth Century"
topic: "Free Speech"
draft: false
---

*This excerpt is from Chapter 6 of, [“For A New Liberty: The Libertarian Manifesto”](https://mises.org/library/new-liberty-libertarian-manifesto), By Murray Rothbard*

**Personal Liberty, Property Rights, and Free Speech**

There are, of course, many problems of personal liberty which cannot be subsumed under the category of “involuntary servitude.” Freedom of speech and press have long been treasured by those who confine themselves to being “civil libertarians”—”civil” meaning that economic freedom and the rights of private property are left out of the equation. But we have already seen that “freedom of speech” cannot be upheld as an absolute except as it is subsumed under the general rights of property of the individual (emphatically *including* property right in his own person). Thus, the man who shouts “fire” in a crowded theater has no right to do so because he is aggressing against the contractual property rights of the theater owner and of the patrons of the performance.

Aside from invasions of property, however, freedom of speech will necessarily be upheld to the uttermost by every libertarian. Freedom to say, print, and sell any utterance becomes an absolute right, in whatever area the speech or expression chooses to cover. Here, civil libertarians have a generally good record, and in the judiciary the late Justice Hugo Black was particularly notable in defending freedom of speech from government restriction on the basis of the First Amendment of the Constitution.

But there are areas in which even the most ardent civil libertarians have been unfortunately fuzzy. What, for example, of “incitement to riot,” in which the speaker is held guilty of a crime for whipping up a mob, which then riots and commits various actions and crimes against person and property? In our view, “incitement” can only be considered a crime if we deny every man’s freedom of will and of choice, and assume that if *A* tells *B* and *C*: “You and him go ahead and riot!” that somehow *B* and *C* are then helplessly determined to proceed and commit the wrongful act. But the libertarian, who believes in freedom of the will, must insist that while it might be immoral or unfortunate for *A* to advocate a riot, that this is strictly in the realm of advocacy and should not be subject to legal penalty. Of course, if *A* also participates in the riot, then he himself becomes a rioter and is equally subject to punishment. Furthermore, if *A* is a boss in a criminal enterprise, and, as part of the crime, orders his henchmen: “You and him go and rob such and such a bank,” then of course *A,* according to the law of accessories, becomes a participant or even leader in the criminal enterprise itself.

If advocacy should never be a crime, then neither should“conspiracy to advocate,” for, in contrast to the unfortunatedevelopment of conspiracy law, “conspiring” (i.e., agreeing)to do something should never be more illegal than the actitself. (How, in fact, can “conspiracy” be defined except as anagreement by two or more people to do something that you,the definer, do not like?) [^1]

Another difficult zone is the law of libel and slander. It has generally been held legitimate to restrict freedom of speech if that speech has the effect of either falsely or maliciously dam-aging the reputation of another person. What the law of libel and slander does, in short, is to argue a “property right” of someone in his own reputation. Yet someone’s “reputation” is not and cannot be “owned” by him, since it is purely a function of the subjective feelings and attitudes held by other people. But since no one can ever truly “own the mind and attitude of another, this means that no one can literally have a property right in his “reputation.” A person’s reputation fluctuates all the time, in accordance with the attitudes and opinions of the rest of the population. Hence, speech attacking someone cannot be an invasion of his property right and therefore should not be subject to restriction or legal penalty.

It is, of course, immoral to level false charges against another person, but once again, the *moral* and the *legal* are, for the libertarian, two very different categories.

Furthermore, pragmatically, if there were no laws of libel or slander, people would be much less willing to credit charges without full documentation than they are now. Nowadays, if a man is charged with some flaw or misdeed, the general reaction is to believe it, since if the charge were false, “Why doesn’t he sue for libel?” The law of libel, of course, discriminates in this way against the poor, since a person with few financial resources is scarcely as ready to carry on a costly libel suit as a person of affluent means. Furthermore, wealthy people can now use the libel laws as a club against poorer per-sons, restricting perfectly legitimate charges and utterances under the threat of suing their poorer enemies for libel. Paradoxically, then, a person of limited resources is more apt to suffer from libel—and to have his own speech restricted—in the present system than he would in a world without any laws against libel or defamation.

Fortunately, in recent years the laws against libel have been progressively weakened, so that one can now deliver vigorous and trenchant criticisms of public officials and of people in the public eye without fear of being subject to costly legal action or legal punishment.

Another action that should be completely free of restriction is the boycott. In a boycott, one or more people use their right of speech to urge, for whatever reasons—important or trivial—that other people cease to buy someone else’s product.

If, for example, several people organize a campaign—for whatever reason—to urge consumers to stop buying XYZ Beer, this is again purely advocacy, and, furthermore, advocacy of a perfectly legitimate act—*not* purchasing the beer. A successful boycott might be unfortunate for the producers of XYZ Beer, but this, again, is strictly within the realm of free speech and the rights of private property. The makers of XYZ Beer take their chances with the free choices of consumers, and consumers are entitled to listen and to be swayed by any-one they choose. Yet our labor laws have infringed upon the right of labor unions to organize boycotts against business firms. It is also illegal, under our banking laws, to spread rumors about the insolvency of a bank—an obvious case of the government’s extending special privileges to banks by outlawing freedom of speech in opposition to their use.

A particularly thorny question is the whole matter of picketing and demonstrations. Freedom of speech implies, of course, freedom of assembly—the freedom to gather together and express oneself in concert with others. But the situation becomes more complex when the use of the *streets* is involved.It is clear that picketing is illegitimate when it is used—as it often is—to block access to a private building or factory, or when the pickets threaten violence against those who cross the picket line. It is also clear that sit-ins are an illegitimate invasion of private property. But even “peaceful picketing” is not clearly legitimate, for it is part of a wider problem: Who decides on the use of the streets? The problem stems from the fact that the streets are almost universally owned by (local)government. But the government, not being a private owner, lacks any criterion for allocating the use of its streets, so that any decision it makes will be arbitrary.

Suppose, for example, that the Friends of Wisteria wish to demonstrate and parade on behalf of Wisteria in a public street. The police ban the demonstration, claiming that it will clog the streets and disrupt traffic. Civil libertarians will automatically protest and claim that the “right of free speech” of the Wisteria demonstrators is being unjustly abridged. But the police, too, may have a perfectly legitimate point: the streets may well be clogged, and it is the government’s responsibility to maintain the flow of traffic. How then decide? Whichever way the government decides, *some* group of taxpayers will be injured by the decision. If the government decides to allow the demonstration, the motorists or pedestrians will be injured; if it does not, then the Friends of Wisteria will suffer a loss. In either case, the very fact of government decision-making generates inevitable conflict over who shall, and who shall not among the taxpayers and citizens, use the governmental resource.

It is only the universal fact of government ownership and control of the streets that makes this problem insoluble and cloaks the true solution to it. The point is that *whoever* owns a resource will decide on how that resource is to be used. The owner of a press will decide what will be printed on that press. And the owner of the streets will decide how to allocate their use. In short, if the streets were privately owned and the Friends of Wisteria asked for the use of Fifth Avenue to demonstrate, it will be up to the owner of Fifth Avenue to decide whether to rent the street for demonstration use or to keep it clear for traffic. In a purely libertarian world, where all streets are privately owned, the various street owners will decide, at any given time, whether to rent out the street for demonstrations, whom to rent it to, and what price to charge. It would then be clear that what is involved is not a “free speech” or “free assembly” question at all, but a question of property rights: of the right of a group to offer to rent a street, and of the right of the street owner either to accept or reject the offer.

FREEDOM OF RADIO AND TELEVISION

There is one important area of American life where no effective freedom of speech or the press does or can exist under the present system. That is the entire field of radio and television. In this area, the federal government, in the crucially important Radio Act of 1927, nationalized the airwaves. In effect, the federal government took title to ownership of all radio and television channels. It then presumed to grant licenses, at its will or pleasure, for use of the channels to various privately owned stations. On the one hand, the stations, since they receive the licenses gratis, do not have to pay for the use of the scarce airwaves, as they would on the free market.And so these stations receive a huge subsidy, which they are eager to maintain. But on the other hand, the federal government, as the licensor of the airwaves, asserts the right and the power to regulate the stations minutely and continuously.Thus, over the head of each station is the club of the threat of non-renewal, or even suspension, of its license. In consequence, the idea of freedom of speech in radio and television is no more than a mockery. Every station is grievously restricted, and forced to fashion its programming to the dictates of the Federal Communications Commission. So every station must have “balanced” programming, broadcast a certain amount of “public service” announcements, grant equal time to every political candidate for the same office and to expressions of political opinion, censor “controversial” lyrics in the records it plays, etc. For many years, no station was allowed to broadcast any editorial opinion at all; now, every opinion must be balanced by “responsible” editorial rebuttals. Because every station and every broadcaster must always look over its shoulder at the FCC, free expression in broadcasting is a sham. Is it any wonder that television opinion, when it is expressed at all on controversial issues, tends to be blandly in favor of the “Establishment”?

The public has only put up with this situation because it has existed since the beginning of large-scale commercial radio. But what would we think, for example, if all newspapers were licensed, the licenses to be renewable by a FederalPress Commission, and with newspapers losing their licenses if they dare express an “unfair” editorial opinion, or if they don’t give full weight to public service announcements? Would not this be an intolerable, not to say unconstitutional, destruction of the right to a free press? Or consider if all book publishers had to be licensed, and their licenses were not renewable if their book lists failed to suit a Federal Book Com-mission? Yet what we would all consider intolerable and totalitarian for the press and the book publishers is taken for granted in a medium which is now the most popular vehicle for expression and education: radio and television. Yet the principles in both cases are exactly the same.

Here we see, too, one of the fatal flaws in the idea of “democratic socialism,” i.e., the idea that the government should own all resources and means of production yet preserve and maintain freedom of speech and the press for all its citizens.An abstract constitution guaranteeing “freedom of the press”is meaningless in a socialist society. The point is that where the government owns all the newsprint, the paper, the presses, etc., the government—as owner—*must* decide how to allocate the newsprint and the paper, and what to print on them. Justas the government as street owner must make a decision how the street will be used, so a socialist government will have to decide how to allocate newsprint and all other resources involved in the areas of speech and press: assembly halls, machines, trucks, etc. Any government may profess its devotion to freedom of the press, yet allocate all of its newsprint only to its defenders and supporters. A free press is again a mockery; furthermore, why *should* a socialist government allocate any considerable amount of its scarce resources to anti-socialists? The problem of genuine freedom of the press then becomes insoluble.

The solution for radio and television? Simple: Treat these media precisely the same way the press and book publishers are treated. For both the libertarian and the believer in theAmerican Constitution the government should withdraw completely from any role or interference in all media of expression. In short, the federal government should denationalize the airwaves and give or sell the individual channels to private ownership. When private stations genuinely own their channels, they will be truly free and independent; they will be able to put on any programs they wish to produce, or that they feel their listeners want to hear; and they will be able to express themselves in whichever way they wish without fear of government retaliation. They will also be able to sell or rent the airwaves to whomever they wish, and in that way the users of the channels will no longer be artificially subsidized.

Furthermore, if TV channels become free, privately owned, and independent, the big networks will no longer be able to put pressure upon the FCC to outlaw the effective com-petition of pay-television. It is only because the FCC has out-lawed pay-TV that it has not been able to gain a foothold.“Free TV” is, of course, not truly “free”; the programs are paid for by the advertisers, and the consumer pays by covering the advertising costs in the price of the product he buys. One might ask what difference it makes to the consumer whether he pays the advertising costs indirectly or pays directly foreach program he buys. The difference is that these are not the same consumers for the same products. The television advertiser, for example, is always interested in (a) gaining the widest possible viewing market; and (b) in gaining those *particular* viewers who will be most susceptible to his message.Hence, the programs will all be geared to the lowest common denominator in the audience, and particularly to those viewers most susceptible to the message; that is, those viewers who do not read newspapers or magazines, so that the message will not duplicate the ads he sees there. As a result, free-TV programs tend to be unimaginative, bland, and uniform. Pay-TV would mean that each program would search for its own market, and many specialized markets for specialized audiences would develop—just as highly lucrative specialized markets have developed in the magazine and book publishing fields. The quality of programs would be higher and the offerings far more diverse. In fact, the menace of potential pay-TV competition must be great for the networks to lobby for years to keep it suppressed. But, of course, in a truly free market, both forms of television, as well as cable-TV and other forms we cannot yet envision, could and would enter the competition.

One common argument against private ownership of TV channels is that these channels are “scarce,” and therefore have to be owned and parceled out by the government. To an economist, this is a silly argument; *all* resources are scarce, in fact anything that has a price on the market commands that price precisely *because* it is scarce. We have to pay a certain amount for a loaf of bread, for shoes, for dresses *because* they are all scarce. If they were not scarce but superabundant like air, they would be free, and no one would have to worry about their production or allocation. In the press area, newsprint is scarce, paper is scarce, printing machinery and trucks are scarce, etc. The more scarce they are the higher the price they will command, and vice versa. Furthermore, and again pragmatically, there are far more television channels available than are now in use. The FCC’s early decision to force stations into the VHF instead of the UHF zone created far more of a scarcity of channels than there needed to be.

Another common objection to private property in the broadcast media is that private stations would interfere with each other’s broadcasts, and that such widespread interference would virtually prevent any programs from being heard or seen. But this is as absurd an argument for nationalizing the airwaves as claiming that since people *can* drive their cars over other people’s land this means that all cars—or land—must be nationalized. The problem, in either case, is for the courts to demarcate property titles carefully enough so that any invasion of another’s property will be clear-cut and subject to prosecution. In the case of land titles, this process is clear enough. But the point is that the courts can apply a similar process of staking out property rights in other areas—whether it be in airwaves, in water, or in oil pools. In the case of airwaves, the task is to find the technological unit—i.e., the place of transmission, the distance of the wave, and the technological width of a clear channel—and then to allocate property rights to this particular technological unit. If radio stationWXYZ, for example, is assigned a property right in broadcasting on 1500 kilocycles, plus or minus a certain width of kilo-cycles, for 200 miles around Detroit, then any station which subsequently beams a program into the Detroit area on this wavelength would be subject to prosecution for interference with property rights. If the courts pursue their task of demarking and defending property rights, then there is no more reason to expect continual invasions of such rights in this area than anywhere else.

Most people believe that this is precisely the reason the airwaves were nationalized; that before the Radio Act of 1927, stations interfered with each other’s signals and chaos ensued, and the federal government was finally forced to step in to bring order and make a radio industry feasible at last. But this is historical legend, not fact. The actual history is *precisely the opposite*. For when interference on the same channel began to occur, the injured party took the airwave aggressors into court, and the courts were beginning to bring order out of the chaos by very successfully applying the common law theory of property rights—in very many ways similar to the libertarian theory—to this new technological area. In short, the courts were beginning to assign property rights in the airwaves to their “homesteading” users. It was after the federal government saw the likelihood of this new extension of private property that it rushed in to nationalize the airwaves, using alleged chaos as the excuse.

To describe the picture a bit more fully, radio in the first years of the century was almost wholly a means of communication for ships—either ship-to-ship or ship-to-shore messages. The Navy Department was interested in regulating radio as a means of ensuring safety at sea, and the initial federal regulation, a 1912 act, merely provided that any radio station had to have a license issued by the Secretary of Commerce. No powers to regulate or to decide not to renew licenses were written into the law, however, and when public broadcasting began in the early 1920s, Secretary of CommerceHerbert Hoover attempted to regulate the stations. Court deci-sions in 1923 and 1926, however, struck down the government’s power to regulate licenses, to fail to renew them, or even to decide on which wavelengths the stations should operate. [^2] At about the same time, the courts were working out the concept of “homestead” private property rights in the airwaves, notably in the case of *Tribune Co. v. Oak Leaves Broadcasting Station* (Circuit Court, Cook County, Illinois, 1926). In this case the court held that the operator of an existing station had a property right, acquired by prior use, sufficient to enjoin anew station from using a radio frequency in any way so as to cause interference with the signals of the prior station. [^3] And so order was being brought out of the chaos by means of the assignment of property rights. But it was precisely this development that the government rushed in to forestall.

The 1926 Zenith decision striking down the government’s power to regulate or to fail to renew licenses, and forcing theDepartment of Commerce to issue licenses to any station that applied, produced a great boom in the broadcasting industry.Over two hundred new stations were created in the nine months after the decision. As a result, Congress rushed through a stopgap measure in July 1926 to *prevent* any property rights in radio frequencies, and resolved that all licenses should be limited to 90 days. By February 1927 the Congress passed the law establishing the Federal Radio Commission, which nationalized the airwaves and established powers similar to those of the current FCC. That the aim of the knowledgeable politicians was *not* to prevent chaos but to prevent private property in the airwaves as the solution to chaos is demonstrated by the legal historian H.P. Warner. Warner states that “grave fears were expressed by legislators, and those generally charged with the administration of communications… that government regulation of an effective sort might be permanently prevented through the accrual of property rights in licenses or means of access, and that thus franchises of the value of millions of dollars might be established for all time.” [^4] The net result, however, was to establish equally valuable franchises anyway, but in a monopolistic fashion through the largesse of the Federal Radio Commission and later FCC rather than through competitive homesteading.

Among the numerous direct invasions of freedom of speech exercised by the licensing power of the FRC and FCC, two cases will suffice. One was in 1931, when the FRC denied renewal of license to a Mr. Baker, who operated a radio station in Iowa. In denying renewal, the Commission said:

> This Commission holds no brief for the Medical Associations and other parties whom Mr. Baker does not like. Their alleged sins may be at times of public importance, to be called to the attention of the public over the air in the right way. But this record discloses that Mr. Baker does not do so in any high-minded way. It shows that he continually and erratically over the air rides a personal hobby, his cancer cure ideas and his likes and dislikes of certain persons and things. Surely his infliction of all this on the listeners is not the proper use of a broadcasting license. Many of his utterances are vulgar, if not indeed indecent. Assuredly they are not uplifting or entertaining. [^5]

Can we imagine the outcry if the federal government were to put a newspaper or a book publisher out of business on similar grounds?

A recent act of the FCC was to threaten non-renewal of license of radio station KTRG in Honolulu, a major radio station in Hawaii. KTRG had been broadcasting libertarian programs for several hours a day for approximately two years. Finally, in late 1970, the FCC decided to open lengthy hearings moving toward non-renewal of license, the threatened cost of which forced the owners to shut down the station permanently. [^6]

[^1]: For a critique of the “clear and present danger” criterion as insufficient for drawing a clear line between advocacy and overt act, see Alexander Meiklejohn, *Political Freedom* (New York: Harper and Bros., 1960), pp.29–50; and O. John Rogge, *The First and the Fifth* (New York: ThomasNelson and Sons, 1960), pp. 88ff.
[^2]: In the decisions *Hoover v. Intercity Radio Co.*, 286 Fed. 1003 (AppealsD.C., 1923); and *United States v. Zenith Radio Corp.*, 12 F. 2d 614 (ND. Ill.,1926). See the excellent article by Ronald H. Coase, “The Federal Communications Commission,” *Journal of Law and Economics* (October 1959):4–5.
[^3]: Ibid., p. 31n.
[^4]: Harry P. Warner, *Radio and Television Law* (1958), p. 540. Quoted in Coase, “The Federal Communications Commission,” p. 32.
[^5]: Decisions of the FRC, Docket No. 967, June 5, 1931. Quoted in Coase, “The Federal Communications Commission,” p. 9.
[^6]: The best and most fully elaborated portrayal of how private property rights could be assigned in radio and television is in A. DeVany et al., “A Property System for Market Allocation of the Electromagnetic Spectrum: A Legal-Economic-Engineering Study,” *Stanford Law Review* (June 1969). See also William H. Meckling, “National Communications Policy: Discussion,” *American Economic Review, Papers and Proceedings* (May 1970): 222–23. Since the DeVany article, the growth of community.